@@ -54,7 +54,8 @@ sub uri {
 sub isWorldRecord {
 	my $this = shift();
 	#warn "*", $this->displayName(), " layer = '", $this->layer(), "' from {", join(",", sort keys %{$this->{layers}}), "}";
-	return !exists $this->{layers}->{override};
+	return (!exists $this->{layers}->{override} &&
+		!exists $this->{layers}->{'master-override'});
 }
 
 
@@ -102,6 +103,19 @@ sub field {
     return $layer->field($name);
 }
 
+sub setField {
+    my $this = shift();
+    my($name, $value) = @_;
+
+    # Currently only needed for master records, so to avoid surprises
+    # we reject the call if this is not a master.
+    
+    die "setField() called on non-Master record"
+	if !exists $this->{layers}->{'master-override'};
+
+
+}
+
 sub _show {
     my($val) = @_;
     return "is undefined" if !defined $val;
