@@ -74,7 +74,7 @@ sub get_path {
 
     $path =~ s,%{(.*?)},$param->{$1},ge;
 
-    warn "replace @{[ $args{'path'} ]} with $path\n" if 1;
+    warn "replace @{[ $args{'path'} ]} with $path\n" if $self->debug;
     return $path;
 }
 
